@@ -31,8 +31,7 @@
 #' @param event_model The event model used to analyze the event data
 #'   which can be set to one of the following options:
 #'   "exponential", "Weibull", "log-logistic", "log-normal",
-#'   "piecewise exponential", "model averaging", "spline", or
-#'   "cox model".
+#'   "piecewise exponential", "model averaging", "spline", or "cox".
 #'   The model averaging uses the \code{exp(-bic/2)} weighting and
 #'   combines Weibull and log-normal models. By default, it is set to
 #'   "model averaging".
@@ -57,8 +56,7 @@
 #' @param dropout_model The dropout model used to analyze the dropout data
 #'   which can be set to one of the following options:
 #'   "none", "exponential", "Weibull", "log-logistic", "log-normal",
-#'   "piecewise exponential", "model averaging", "spline", or
-#'   "cox model".
+#'   "piecewise exponential", "model averaging", "spline", or "cox".
 #'   The model averaging uses the \code{exp(-bic/2)} weighting and
 #'   combines Weibull and log-normal models. By default, it is set to
 #'   "exponential".
@@ -168,7 +166,7 @@
 #' should also include \code{piecewiseSurvivalTime}
 #' (\code{piecewiseDropoutTime}) to indicate the location of knots.
 #' It should be noted that the model averaging, spline, and
-#' cox model options are not appropriate for use as prior.
+#' cox options are not appropriate for use as prior.
 #'
 #' If the event prediction is not by treatment while the prior
 #' information is given by treatment, then each element of
@@ -355,7 +353,7 @@ getPrediction <- function(
   erify::check_content(tolower(event_model),
                        c("exponential", "weibull", "log-logistic",
                          "log-normal", "piecewise exponential",
-                         "model averaging", "spline", "cox model"))
+                         "model averaging", "spline", "cox"))
 
   if (piecewiseSurvivalTime[1] != 0) {
     stop("piecewiseSurvivalTime must start with 0")
@@ -446,7 +444,7 @@ getPrediction <- function(
   erify::check_content(tolower(dropout_model),
                        c("none", "exponential", "weibull", "log-logistic",
                          "log-normal", "piecewise exponential",
-                         "model averaging", "spline", "cox model"))
+                         "model averaging", "spline", "cox"))
 
   if (piecewiseDropoutTime[1] != 0) {
     stop("piecewiseDropoutTime must start with 0")
